#!/bin/bash
if [[ $HOSTNAME = *"occigen"* ]]; then
        source ../machines/occigen-bdw/env
	module switch intel/18.1 intel/17.2
        module load python/3.6.3
elif [[ $HOSTNAME = *"jean-zay"* ]]; then
        source ../machines/jean-zay-cpu/env
        module load python/3.7.5
elif [[ $HOSTNAME = *"irene"* ]]; then
        source ../machines/irene-amd/env
	module load python3/3.7.5
else
        echo "Hostname not recognized: abort"
        exit 1
fi
echo "*******************************************************************************************************************"
echo "* Validate Large case in $bench_dir/testcase_large/ *"
echo "*******************************************************************************************************************"
cd $bench_dir/testcase_large
echo "* ls -1 *.log" && ls -1 *.log
log_file=$1
if [ -z "$log_file" ]; then
	log_file=`ls -thlx1 run_* | awk 'NR < 2'`
        echo "* No argument provided (ex: ./validate run_%m-%d-%y-%H-%M-%S.log) -> validation of the last run named $log_file"
else
	echo "* Validation of the run named $log_file"
fi
start_t=`grep startup $log_file | awk '{ print $5 }'`
end_t=`grep "Total elapsed time:"  $log_file | awk '{ print $4 }'`
perf=`bc -l <<< $end_t-$start_t`

if [ -z "$perf" ] || [ -z "$end_t" ]
then
    echo "***************************************"
    echo "* NOK -> Large bench is not validated *"
    echo "***************************************"
else
    echo "***********************************"
    echo "* => OK Large bench is validated *"
    echo "***********************************"
    a=`grep $log_file metric-large.log | wc -l`
    if [ "$a" -lt "1" ]; then
	echo "log file: $log_file" >> metric-large.log
        echo "end = $end_t s (total simulation time)" >> metric-large.log
        echo "perf = $perf s (total simulation time excluding initialization and i/o)" >> metric-large.log
        echo "***********************************************************************************" >> metric-large.log
    else
        echo "Metrics already written in metric-large.log"
    fi
fi
echo "***********************************"
echo "* Physical validation Medium case *"
echo "***********************************"
dt=`grep -B 1 "Run completed" $log_file | grep dt | awk -F ' ' '{print $6}'`
exp_simu=`grep -B 1 "Run completed" $log_file | grep dt | awk -F ' ' '{print $6}' | awk -F 'E' '{print $2}'`
echo "dt=" $dt
echo "exponent="$exp_simu
cd -
exp_ref=-5 # Defined and validated with an astrophysicist 
abs_tol=1  # minimum absolute tolerance
python3 ../tools/isclose.py $exp_ref $exp_simu $abs_tol
# Copy log file
mkdir -p resluts-RAMSES-large
cp $bench_dir/testcase_large/$log_file $bench_dir/testcase_large/metric-large.log resluts-RAMSES-large/.
tail -n 4 resluts-RAMSES-large/metric-large.log
