#!/bin/bash
if [[ $HOSTNAME = *"occigen"* ]]; then
        source ../machines/occigen-bdw/env
	module switch intel/18.1 intel/17.2 
	module load python/3.6.3
elif [[ $HOSTNAME = *"jean-zay"* ]]; then
        source ../machines/jean-zay-cpu/env
	module load python/3.7.5
elif [[ $HOSTNAME = *"irene"* ]]; then
        source ../machines/irene-amd/env
	module load python3/3.7.5
else
        echo "Hostname not recognized: abort"
        exit 1
fi
echo "**********************************************************************************************************"
echo "* Validate small case in $bench_dir/DEBUG *"
echo "**********************************************************************************************************"
cd $bench_dir/DEBUG
echo "* ls -1 *.log" && ls -1 *.log
log_file=$1
if [ -z "$log_file" ]; then
	log_file=`ls -thlx1 run_* | awk 'NR < 2'`
	echo "* No argument provided (ex: ./validate run_%m-%d-%y-%H-%M-%S.log), validation of the last run named $log_file"	
else
        echo "* Validation of the run named $log_file"
fi
start_t=`grep startup $log_file | awk '{ print $5 }'`
end_t=`grep "Total elapsed time:"  $log_file | awk '{ print $4 }'`
perf=`bc -l <<< $end_t-$start_t`

if [ -z "$perf" ] || [ -z "$end_t" ]
then
    echo "***************************************"
    echo "* NOK -> Small bench is not validated *"
    echo "***************************************"
else
    echo "***********************************"
    echo "* => OK Small bench is validated  *"
    echo "***********************************"
    a=`grep $log_file metric-small.log | wc -l`
    if [ "$a" -lt "1" ]; then
	echo "log file: $log_file" >> metric-small.log
        echo "end = $end_t s (total simulation time)" >> metric-small.log
        echo "perf = $perf s (total simulation time excluding initialization and i/o)" >> metric-small.log
        echo "***********************************************************************************" >> metric-small.log
    else
	echo "Metrics already written in metric-small.log"
    fi
fi
echo "***********************************"
echo "* Physical validation Medium case *"
echo "***********************************"
dt=`grep -B 1 "Run completed" $log_file | grep dt | awk -F ' ' '{print $6}'`
exp_simu=`grep -B 1 "Run completed" $log_file | grep dt | awk -F ' ' '{print $6}' | awk -F 'E' '{print $2}'`
echo "dt simu=" $dt
ref_log_file=$bench_dir/DEBUG/run_2020-01-15_14h02.log
dt_ref=`grep -B 1 "Run completed" $ref_log_file | grep dt | awk -F ' ' '{print $6}'`
exp_ref=`grep -B 1 "Run completed" $ref_log_file | grep dt | awk -F ' ' '{print $6}' | awk -F 'E' '{print $2}'` # results validated by the scientist
echo "dt ref=" $dt_ref
abs_tol=1  # minimum absolute tolerance
cd -
python3 ../tools/isclose.py $exp_ref $exp_simu $abs_tol
# Copy log file
mkdir -p resluts-RAMSES-DEBUG
cp $bench_dir/DEBUG/$log_file $bench_dir/DEBUG/metric-small.log resluts-RAMSES-DEBUG/.
tail -n 4 resluts-RAMSES-DEBUG/metric-small.log
